Module: Lifer::Builder::InitializeBuilder
- Defined in:
- lib/lifer/builder.rb
Overview
When any new builder instance is initialized, we need to ensure that any
settings specific to the builder are registered. We can do this automatically
by wrapping the #initialize method. This module provides the wrapper
functionality--we just need to ensure that this module is included.