Class: Lifer::Selection::AllMarkdown

Inherits:
Lifer::Selection show all
Defined in:
lib/lifer/selection/all_markdown.rb

Overview

This selection provides a list of all Markdown entries from all collections.

To provide this to Lifer, configure it in your selections:

selections:
  - lifer/selection/all_markdown

Method Summary

Methods inherited from Lifer::Selection

generate, #setting