Class: Lifer::Selection::IncludedInFeeds

Inherits:
Lifer::Selection show all
Defined in:
lib/lifer/selection/included_in_feeds.rb

Overview

This selection provides a list of all entries that can be included in feeds.

To provide this to Lifer, configure it in your selections:

selections:
  - lifer/selection/included_in_feeds

Method Summary

Methods inherited from Lifer::Selection

generate, #setting